@@ -1,13 +1,11 @@
-require 'tmpdir'
-require 'hiera/backend/yaml_backend'
-require 'hiera/backend'
-require 'fileutils'
 require 'spec_helper'
+require 'hiera/backend/yaml_backend'
 
 class Hiera
   module Backend
     describe Yaml_backend do
       before do
+        Config.load({})
         Hiera.stubs(:debug)
         Hiera.stubs(:warn)
         @backend = Yaml_backend.new
